==> nodejs_interop-0.7.0.tar.gz: lib/src/npm/readdir_enhanced.dart <==
part of nodejs_interop.npm;

/// The [`readdir-enhanced`](https://www.npmjs.com/package/readdir-enhanced) module.
@JS()
abstract class ReaddirModule implements Function {

  /// An alias for the [readdirAsync] method.
  external dynamic call(String path, [optionsOrCallback, CompletionCallback1<List<String>> callback]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// If no [callback] is provided, the result is a `Promise` that resolves with the list of paths for the directories, files, and links.
  /// If a [callback] is provided, it is called with the list of paths.
  external dynamic readdirAsync(String path, [optionsOrCallback, CompletionCallback1<List<String>> callback]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// If no [callback] is provided, the result is a `Promise` that resolves with the list of [Stats] objects for the directories, files, and links.
  /// If a [callback] is provided, it is called with the list of [Stats] objects.
  external dynamic readdirAsyncStat(String path, [optionsOrCallback, CompletionCallback1<List<Stats>> callback]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a [Readable] stream of paths for the directories, files, and links.
  external Readable<String> readdirStream(String path, [ReaddirOptions options]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a [Readable] stream of [Stats] objects for the directories, files, and links.
  external Readable<Stats> readdirStreamStat(String path, [ReaddirOptions options]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a list of paths for the directories, files, and links.
  external List<String> readdirSync(String path, [ReaddirOptions options]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a list of [Stats] objects for the directories, files, and links.
  external List<Stats> readdirSyncStat(String path, [ReaddirOptions options]);

  /// An alias for the [readdirStream] method.
  external Readable<String> stream(String path, [ReaddirOptions options]);

  /// An alias for the [readdirSync] method.
  external List<String> sync(String path, [ReaddirOptions options]);
}

/// Options used to customize the directory listing.
@JS()
@anonymous
class ReaddirOptions {

  /// Creates a new options object.
  external factory ReaddirOptions({String basePath, bool deep = false, filter, String sep});

  /// The base path to be prepended to all of the returned paths.
  external String get basePath;
  external set basePath(String value);

  /// Value customizing how to recurse into sub-directories. It can be:
  /// - a boolean: whether to crawl all sub-directories.
  /// - an integer: crawl to a specific depth.
  /// - a glob pattern or a regular expression: crawl sub-directories by name.
  /// - a function: use a custom recursion logic.
  external dynamic get deep;
  external set deep(value);

  /// Value customizing how to filter the returned paths. It can be:
  /// - a glob pattern or a regular expression: filter by name.
  /// - a function: use a custom filtering logic.
  external dynamic get filter;
  external set filter(value);

  /// The path separator of the returned paths. Defaults to the operating system one.
  external String get sep;
  external set sep(String value);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/npm/readdir_enhanced.dart <==
/// Support for interoperating with [`readdir-enhanced`](https://www.npmjs.com/package/readdir-enhanced) package.
@JS()
library nodejs_interop.npm.readdir_enhanced;

import 'package:js/js.dart';
import 'package:nodejs_interop/node.dart';

/// The [`readdir-enhanced`](https://www.npmjs.com/package/readdir-enhanced) module.
@JS()
abstract class ReaddirModule implements Function {

  /// An alias for the [readdirAsync] method.
  external dynamic call(String path, [optionsOrCallback, CompletionCallback1<List<String>> callback]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// If no [callback] is provided, the result is a `Promise` that resolves with the list of paths for the directories, files, and links.
  /// If a [callback] is provided, it is called with the list of paths.
  external dynamic readdirAsync(String path, [optionsOrCallback, CompletionCallback1<List<String>> callback]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// If no [callback] is provided, the result is a `Promise` that resolves with the list of [Stats] objects for the directories, files, and links.
  /// If a [callback] is provided, it is called with the list of [Stats] objects.
  external dynamic readdirAsyncStat(String path, [optionsOrCallback, CompletionCallback1<List<Stats>> callback]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a [Readable] stream of paths for the directories, files, and links.
  external Readable<String> readdirStream(String path, [ReaddirOptions options]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a [Readable] stream of [Stats] objects for the directories, files, and links.
  external Readable<Stats> readdirStreamStat(String path, [ReaddirOptions options]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a list of paths for the directories, files, and links.
  external List<String> readdirSync(String path, [ReaddirOptions options]);

  /// Lists the sub-directories and files of the directory at [path]. Optionally recurses into sub-directories.
  /// The result is a list of [Stats] objects for the directories, files, and links.
  external List<Stats> readdirSyncStat(String path, [ReaddirOptions options]);

  /// An alias for the [readdirStream] method.
  external Readable<String> stream(String path, [ReaddirOptions options]);

  /// An alias for the [readdirSync] method.
  external List<String> sync(String path, [ReaddirOptions options]);
}

/// Options used to customize the directory listing.
@JS()
@anonymous
class ReaddirOptions {

  /// Creates a new options object.
  external factory ReaddirOptions({String basePath, deep = false, filter, String sep});

  /// The base path to be prepended to all of the returned paths.
  external String get basePath;
  external set basePath(String value);

  /// Value customizing how to recurse into sub-directories. It can be:
  /// - a boolean: whether to crawl all sub-directories.
  /// - an integer: crawl to a specific depth.
  /// - a glob pattern or a regular expression: crawl sub-directories by name.
  /// - a function: use a custom recursion logic.
  external dynamic get deep;
  external set deep(value);

  /// Value customizing how to filter the returned paths. It can be:
  /// - a glob pattern or a regular expression: filter by name.
  /// - a function: use a custom filtering logic.
  external dynamic get filter;
  external set filter(value);

  /// The path separator of the returned paths. Defaults to the operating system one.
  external String get sep;
  external set sep(String value);
}
